fit_slim: Fitter Function for Singular Linear Models

View source: R/slim.R

fit_slimR Documentation

Fitter Function for Singular Linear Models

Description

This function computes the limiting solution to the estimating equation sum(x' V^(-1) (y - x beta)) = 0 as the covariance V tends from V[, , 1] + V[, , 2] to V[, , 1].

Usage

fit_slim(x, V, y)

Arguments

x

list of design matrices, one for each subject, all having the same number of columns.

V

list of covariance arrays, one for each subject, matching the dimensions of y.

y

list of response vectors, one for each subject.

Value

a list with components coefficients (the limiting solution), residuals, fitted_values, vcov_empirical and vcov_modelled.


slim documentation built on Aug. 24, 2026, 5:08 p.m.