| print.slim | R Documentation |
'print' methods for class 'slim' and 'slim_summary'. 'print.slim_summary' differs only in its default value of 'empirical'.
## S3 method for class 'slim'
print(
x,
empirical = TRUE,
digits = max(3, getOption("digits") - 3),
signif.stars = getOption("show.signif.stars"),
...
)
## S3 method for class 'slim_summary'
print(x, empirical = x$empirical, ...)
x |
an object of class 'slim' or 'slim_summary', as appropriate. |
empirical |
logical indicating if empirical variances of y should be used in estimating standard errors (the default). Empirical standard errors should be used unless covariances have been well modelled. |
digits |
minimal number of significant digits, see
|
signif.stars |
logical. If |
... |
further arguments passed to or from other methods. |
x, invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.